@@ -22,10 +22,10 @@ sub switch {
 
 	### return references to ID classes in symbol table
 	given ($s) {
-	when (Cobol::Compiler::ProgramToken->IDENTIFICATION) {
+	when ("IDENTIFICATION" or Cobol::Compiler::ProgramToken->IDENTIFICATION) {
 		return \$self->{mastersymtab}->{IDENTIFICATION}	
 	}
-	when (Cobol::Compiler::ProgramToken->PROGRAM-ID) { 
+	when ("PROGRAM-ID" or Cobol::Compiler::ProgramToken->PROGRAM-ID) { 
 		return \$self->{mastersymtab}->{PROGRAM-ID}	
 	}
 
