@@ -1,4 +1,4 @@
-package Cobol::Compiler::ProcedureList;
+package Cobol::Compiler::DataList;
 
 sub new {
 	my ($class) = @_;
