@@ -1,6 +1,6 @@
-package Cobol::Compiler::ProcedureTokenInstaller;
+package Cobol::Compiler::ProgramTokenInstaller;
 
-### This is a string token installer to the ProcedureID class
+### This is a string token installer to the ProgramID class
 
 use parent 'TokenInstaller';
 
